pub fn resolve_platform() -> LauncherResult<Platform>Expand description
Map the current platform and architecture to the bundle naming tokens.
Returns an error on unsupported OS/arch combinations.
pub fn resolve_platform() -> LauncherResult<Platform>Map the current platform and architecture to the bundle naming tokens.
Returns an error on unsupported OS/arch combinations.