pub struct HttpForwardWithFallback {
pub http_forward: HttpForward,
pub fallback_response: HttpResponse,
pub fallback_on_status_codes: Option<Vec<i32>>,
pub fallback_on_timeout: Option<bool>,
pub delay: Option<Delay>,
pub primary: Option<bool>,
pub extra: Extra,
}Expand description
Forward action that falls back to a canned response when the upstream fails
(serialised as httpForwardWithFallback).
Fields
http_forward: HttpForwardfallback_response: HttpResponsefallback_on_status_codes: Option<Vec<i32>>fallback_on_timeout: Option<bool>delay: Option<Delay>primary: Option<bool>extra: ExtraImplementations
Sourceimpl HttpForwardWithFallback
impl HttpForwardWithFallback
Sourcepub fn new(http_forward: HttpForward, fallback_response: HttpResponse) -> Self
pub fn new(http_forward: HttpForward, fallback_response: HttpResponse) -> Self
Create a forward-with-fallback action.
Sourcepub fn fallback_on_status_codes(self, codes: Vec<i32>) -> Self
pub fn fallback_on_status_codes(self, codes: Vec<i32>) -> Self
Fall back when the upstream returns any of these status codes.
Sourcepub fn fallback_on_timeout(self, fallback: bool) -> Self
pub fn fallback_on_timeout(self, fallback: bool) -> Self
Fall back when the upstream request times out.