pub struct Expectation {
pub id: Option<String>,
pub priority: Option<i32>,
pub http_request: HttpRequest,
pub http_response: Option<HttpResponse>,
pub http_forward: Option<HttpForward>,
pub http_error: Option<HttpError>,
pub times: Option<Times>,
pub time_to_live: Option<TimeToLive>,
}Expand description
A full expectation combining a request matcher with an action.
Fields
id: Option<String>priority: Option<i32>http_request: HttpRequesthttp_response: Option<HttpResponse>http_forward: Option<HttpForward>http_error: Option<HttpError>times: Option<Times>time_to_live: Option<TimeToLive>Implementations
Sourceimpl Expectation
impl Expectation
Sourcepub fn new(request: HttpRequest) -> Self
pub fn new(request: HttpRequest) -> Self
Create a new expectation with the given request matcher.
Sourcepub fn respond(self, response: HttpResponse) -> Self
pub fn respond(self, response: HttpResponse) -> Self
Set a response action.
Sourcepub fn forward(self, forward: HttpForward) -> Self
pub fn forward(self, forward: HttpForward) -> Self
Set a forward action.
Sourcepub fn time_to_live(self, ttl: TimeToLive) -> Self
pub fn time_to_live(self, ttl: TimeToLive) -> Self
Set the time-to-live.